@@ -1,7 +1,10 @@
+import glob
+import shutil
 import tempfile
 from typing import List, Dict, Tuple, Callable, Any, Optional
 from uuid import uuid4
 
+from shmr import csv_loads
 from shmr.main import main
 
 
@@ -49,4 +52,25 @@ def test_reduce(people):
               "--outfile", temp.name])
 
         temp.seek(0)
-        assert int(temp.read().decode()) == 5047
\ No newline at end of file
+        assert int(temp.read().decode()) == 5047
+
+
+def test_group_by(people, resource_dir):
+    tmp_dir = resource_dir / str(uuid4())
+    tmp_dir.mkdir(exist_ok=True)
+    main(["-i", people[0], "--skip_nrows", "1",
+          "-d", "shmr.csv_loads", "-s",
+          "shmr.str_dumps",
+          "partition.group_by",
+          "--fn", "tests.test_partition.PeopleFunc.get_age",
+          "--num_partitions", "5",
+          "--outfile", str(tmp_dir / "*.csv")])
+
+    assert len(glob.glob(str(tmp_dir / "*.csv"))) == 5
+    for i, file in enumerate(sorted(glob.glob(str(tmp_dir / "*.csv")))):
+        with open(file, "rb") as f:
+            for line in f:
+                assert (PeopleFunc.get_age(csv_loads(line)) - i) % 5 == 0
+
+    if tmp_dir.exists():
+        shutil.rmtree(str(tmp_dir))
\ No newline at end of file
